==> haskell-filemanip-0.3.6.3-196-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filemanip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filemanip
version:              0.3.6.3
visibility:           public
id:                   filemanip-0.3.6.3-5PUVgYI5aZYLjYONWQYRFs
key:                  filemanip-0.3.6.3-5PUVgYI5aZYLjYONWQYRFs
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/filemanip
synopsis:             Expressive file and directory manipulation for Haskell.
description:
    A Haskell library for working with files and directories.
    Includes code for pattern matching, finding files,
    modifying file contents, and more.

category:             System
abi:                  0851907aa9b89e76c701e3aa2724976f
exposed:              True
exposed-modules:
    System.FilePath.Find System.FilePath.Glob
    System.FilePath.GlobPattern System.FilePath.Manip

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filemanip-0.3.6.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filemanip-0.3.6.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filemanip-0.3.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filemanip
hs-libraries:         HSfilemanip-0.3.6.3-5PUVgYI5aZYLjYONWQYRFs
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 unix-compat-0.7.3-GOVtc1SnHFZ96QiKnKkOb0

haddock-interfaces:   /usr/share/doc/haskell-filemanip/html/filemanip.haddock
haddock-html:         /usr/share/doc/haskell-filemanip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filemanip-0.3.6.3-197-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filemanip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filemanip
version:              0.3.6.3
visibility:           public
id:                   filemanip-0.3.6.3-HeatiZngYaIgbJpW59iCo
key:                  filemanip-0.3.6.3-HeatiZngYaIgbJpW59iCo
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/filemanip
synopsis:             Expressive file and directory manipulation for Haskell.
description:
    A Haskell library for working with files and directories.
    Includes code for pattern matching, finding files,
    modifying file contents, and more.

category:             System
abi:                  8a3ad655a503d132484173b4b529aace
exposed:              True
exposed-modules:
    System.FilePath.Find System.FilePath.Glob
    System.FilePath.GlobPattern System.FilePath.Manip

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filemanip-0.3.6.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filemanip-0.3.6.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filemanip-0.3.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filemanip
hs-libraries:         HSfilemanip-0.3.6.3-HeatiZngYaIgbJpW59iCo
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 unix-compat-0.7.3-8nUE2nFGsV44OIFeu9Z7aq

haddock-interfaces:   /usr/share/doc/haskell-filemanip/html/filemanip.haddock
haddock-html:         /usr/share/doc/haskell-filemanip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
